# features
- some form of result viewer
    - for plugins (https://github.com/pytest-dev/pytest/blob/main/scripts/update-plugin-list.py)
    - general overview
- menu dynamic plugin installation+flags (needs uv)
- command preview
- tox-like multi python-version testing
- Improve Filtering/numbers
- Make buttons functional to start/stop test runs

# generals
- test strategy
- Make websocket more performant with queues

# optionals
- align result Icons better on test tree
- using something like watchfiles to detect filechanges and
update the test_tree accordingly (or just stick with a manual refresh)

# fixes
- fix display of skip reason after reset
